@@ -23,16 +23,16 @@ from __future__ import annotations
 from typing import Iterator
 from typing import Optional
 
+import gettext
+import locale
 import os
 import sys
-import locale
-import gettext
 import unicodedata
 from pathlib import Path
+
 from gi.repository import GLib
 
 DOMAIN = 'gajim'
-direction_mark = '\u200E'
 _translation = gettext.NullTranslations()
 
 
@@ -54,7 +54,7 @@ def get_locale_dirs() -> Optional[list[Path]]:
     return [Path(dir_) for dir_ in data_dirs]
 
 
-def iter_locale_dirs() -> Iterator[Optional[str]]:
+def iter_locale_dirs() -> Iterator[Optional[Path]]:
     locale_dirs = get_locale_dirs()
     if locale_dirs is None:
         yield None
@@ -70,7 +70,7 @@ def iter_locale_dirs() -> Iterator[Optional[str]]:
             continue
         found_paths.append(locale_dir)
         if locale_dir.is_dir():
-            yield str(locale_dir)
+            yield locale_dir
 
 
 def get_win32_default_lang() -> str:
@@ -81,16 +81,17 @@ def get_win32_default_lang() -> str:
 
 def get_darwin_default_lang() -> str:
     from AppKit import NSLocale
+
     # FIXME: This returns a two letter language code (en, de, fr)
     # We need a way to get en_US, de_DE etc.
     return NSLocale.currentLocale().languageCode()
 
 
 def get_default_lang() -> str:
-    if sys.platform == "win32":
+    if sys.platform == 'win32':
         return get_win32_default_lang()
 
-    if sys.platform == "darwin":
+    if sys.platform == 'darwin':
         return get_darwin_default_lang()
 
     return locale.getdefaultlocale()[0] or 'en'
@@ -108,54 +109,22 @@ def get_short_lang_code(lang: Optional[str] = None) -> str:
     return lang[:2]
 
 
-def initialize_direction_mark() -> None:
-    from gi.repository import Gtk
-
-    global direction_mark
-
-    if Gtk.Widget.get_default_direction() == Gtk.TextDirection.RTL:
-        direction_mark = '\u200F'
-
-
-def paragraph_direction_mark(text: str) -> str:
-    """
+def is_rtl_text(text: str) -> bool:
+    '''
     Determine paragraph writing direction according to
     http://www.unicode.org/reports/tr9/#The_Paragraph_Level
-
-    Returns either Unicode LTR mark or RTL mark.
-    """
+    '''
     for char in text:
         bidi = unicodedata.bidirectional(char)
         if bidi == 'L':
-            return '\u200E'
+            return False
         if bidi in ('AL', 'R'):
-            return '\u200F'
+            return True
 
-    return '\u200E'
+    return False
 
 
-def Q_(text: str) -> str:
-    """
-    Translate the given text, optionally qualified with a special
-    construction, which will help translators to disambiguate between
-    same terms, but in different contexts.
-
-    When translated text is returned - this rudimentary construction
-    will be stripped off, if it's present.
-
-    Here is the construction to use:
-        Q_("?vcard:Unknown")
-
-    Everything between ? and : - is the qualifier to convey the context
-    to the translators. Everything after : - is the text itself.
-    """
-    text = _(text)
-    if text.startswith('?'):
-        text = text.split(':', 1)[1]
-    return text
-
-
-def P_(context: str, message: str) -> str:
+def p_(context: str, message: str) -> str:
     return _translation.pgettext(context, message)
 
 
@@ -164,18 +133,19 @@ def ngettext(s_sing: str,
              n: int,
              replace_sing: Optional[str] = None,
              replace_plural: Optional[str] = None) -> str:
-    """
+    '''
     Use as:
         i18n.ngettext(
             'leave room %s', 'leave rooms %s', len(rooms), 'a', 'a, b, c')
 
     In other words this is a hack to ngettext() to support %s %d etc..
-    """
+    '''
     text = _translation.ngettext(s_sing, s_plural, n)
     if n == 1 and replace_sing is not None:
-        text = text % replace_sing
-    elif n > 1 and replace_plural is not None:
-        text = text % replace_plural
+        return text % replace_sing
+
+    if n > 1 and replace_plural is not None:
+        return text % replace_plural
     return text
 
 
