@@ -29,27 +29,25 @@ from __future__ import annotations
 from typing import Any
 from typing import Optional
 
-import socket
 import logging
+import socket
 
 import nbxmpp
+from gi.repository import GLib
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import Iq
 from nbxmpp.structs import DiscoInfo
 from nbxmpp.structs import IqProperties
 from nbxmpp.structs import StanzaHandler
 
-from gi.repository import GLib
-
 from gajim.common import app
 from gajim.common import helpers
-from gajim.common import jingle_xtls
 from gajim.common import types
 from gajim.common.events import FileRequestError
 from gajim.common.file_props import FileProp
 from gajim.common.file_props import FilesProp
-from gajim.common.socks5 import Socks5SenderClient
 from gajim.common.modules.base import BaseModule
+from gajim.common.socks5 import Socks5SenderClient
 
 log = logging.getLogger('gajim.c.m.bytestream')
 
@@ -140,15 +138,15 @@ class Bytestream(BaseModule):
         return helpers.parse_jid(streamhost.getAttr('jid'))
 
     def send_file_approval(self, file_props: FileProp) -> None:
-        """
+        '''
         Send iq, confirming that we want to download the file
-        """
+        '''
         # user response to ConfirmationDialog may come after we've disconnected
         if not app.account_is_available(self._account):
             return
 
         # file transfer initiated by a jingle session
-        log.info("send_file_approval: jingle session accept")
+        log.info('send_file_approval: jingle session accept')
 
         session = self._con.get_module('Jingle').get_jingle_session(
             file_props.sender, file_props.sid)
@@ -165,27 +163,17 @@ class Bytestream(BaseModule):
 
         if not session.accepted:
             content = session.get_content('file', content.name)
-            if content.use_security:
-                fingerprint = content.x509_fingerprint
-                if not jingle_xtls.check_cert(
-                        app.get_jid_without_resource(file_props.sender),
-                        fingerprint):
-                    id_ = jingle_xtls.send_cert_request(
-                        self._con, file_props.sender)
-                    jingle_xtls.key_exchange_pend(id_,
-                                                  content.on_cert_received, [])
-                    return
             session.approve_session()
 
         session.approve_content('file', content.name)
 
     def send_file_rejection(self, file_props: FileProp) -> None:
-        """
+        '''
         Inform sender that we refuse to download the file
 
         typ is used when code = '400', in this case typ can be 'stream' for
         invalid stream or 'profile' for invalid profile
-        """
+        '''
         # user response to ConfirmationDialog may come after we've disconnected
         if not app.account_is_available(self._account):
             return
@@ -197,9 +185,9 @@ class Bytestream(BaseModule):
     def send_success_connect_reply(self,
                                    streamhost: Optional[dict[str, Any]]
                                    ) -> None:
-        """
+        '''
         Send reply to the initiator of FT that we made a connection
-        """
+        '''
         if not app.account_is_available(self._account):
             return
         if streamhost is None:
@@ -214,9 +202,9 @@ class Bytestream(BaseModule):
         self._con.connection.send(iq)
 
     def stop_all_active_file_transfers(self, contact: types.ChatContactT):
-        """
+        '''
         Stop all active transfer to or from the given contact
-        """
+        '''
         for file_props in FilesProp.getAllFileProp():
             if is_transfer_stopped(file_props):
                 continue
@@ -236,9 +224,9 @@ class Bytestream(BaseModule):
                 self.remove_transfer(file_props)
 
     def remove_all_transfers(self) -> None:
-        """
+        '''
         Stop and remove all active connections from the socks5 pool
-        """
+        '''
         for file_props in FilesProp.getAllFileProp():
             self.remove_transfer(file_props)
 
@@ -261,9 +249,9 @@ class Bytestream(BaseModule):
                     app.socks5queue.remove_sender(host['idx'])
 
     def _send_socks5_info(self, file_props: FileProp) -> None:
-        """
+        '''
         Send iq for the present streamhosts and proxies
-        """
+        '''
         if not app.account_is_available(self._account):
             return
         receiver = file_props.receiver
@@ -332,7 +320,7 @@ class Bytestream(BaseModule):
             my_ips = [my_ip]
             # all IPs from local DNS
             for addr in socket.getaddrinfo(socket.gethostname(), None):
-                if (not addr[4][0] in my_ips and
+                if (addr[4][0] not in my_ips and
                         not addr[4][0].startswith('127') and
                         not addr[4][0] == '::1'):
                     my_ips.append(addr[4][0])
@@ -371,7 +359,7 @@ class Bytestream(BaseModule):
         # check if we are connected with an IPv4 address
         try:
             socket.inet_aton(my_ip)
-        except socket.error:
+        except OSError:
             self._con.connection.send(iq)
             return
 
@@ -521,9 +509,9 @@ class Bytestream(BaseModule):
 
     @staticmethod
     def _result_socks5_sid(sid: str, hash_id: str) -> None:
-        """
+        '''
         Store the result of SHA message from auth
-        """
+        '''
         file_props = FilesProp.getFilePropBySid(sid)
         file_props.hash_ = hash_id
 
@@ -533,10 +521,10 @@ class Bytestream(BaseModule):
                        error_type: str,
                        msg: Optional[str] = None
                        ) -> None:
-        """
+        '''
         Called when there is an error establishing BS connection, or when
         connection is rejected
-        """
+        '''
         if not app.account_is_available(self._account):
             return
         file_props = FilesProp.getFileProp(self._account, sid)
@@ -563,14 +551,14 @@ class Bytestream(BaseModule):
                                  error_msg=msg))
 
     def _proxy_auth_ok(self, proxy: dict[str, Any]) -> None:
-        """
+        '''
         Called after authentication to proxy server
-        """
+        '''
         if not app.account_is_available(self._account):
             return
         file_props = FilesProp.getFileProp(self._account, proxy['sid'])
         iq = nbxmpp.Iq(to=proxy['initiator'], typ='set')
-        auth_id = "au_" + proxy['sid']
+        auth_id = 'au_' + proxy['sid']
         iq.setID(auth_id)
         query = iq.setTag('query', namespace=Namespace.BYTESTREAM)
         query.setAttr('sid', proxy['sid'])
@@ -609,7 +597,6 @@ class Bytestream(BaseModule):
         id_ = iq_obj.getAttr('id')
         query = iq_obj.getTag('query')
         sid = query.getAttr('sid')
-        file_props = FilesProp.getFileProp(self._account, sid)
         streamhosts: list[dict[str, Any]] = []
         for item in query.getChildren():
             if item.getName() == 'streamhost':
@@ -747,7 +734,6 @@ class Bytestream(BaseModule):
                                         _sock=None,
                                         host=str(proxy['host']),
                                         port=int(proxy['port']),
-                                        fingerprint=None,
                                         connected=False,
                                         file_props=file_props)
             sender.streamhost = proxy
