@@ -1,3 +1,4 @@
+
 # Copyright (C) 2009-2014 Yann Leboulanger <asterix AT lagaule.org>
 #
 # This file is part of Gajim.
@@ -47,13 +48,14 @@ from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.preview import Preview
 from gajim.common.structs import URI
 from gajim.common.util.text import escape_iri_path_segment
-from gajim.gui.structs import AccountJidParam
-from gajim.gui.structs import AddChatActionParams
-from gajim.gui.structs import ChatListEntryParam
-from gajim.gui.structs import RemoveHistoryActionParams
-from gajim.gui.structs import RetractMessageParam
-from gajim.gui.util import GajimMenu
-from gajim.gui.util import MenuItemListT
+
+from gajim.gtk.structs import AccountJidParam
+from gajim.gtk.structs import AddChatActionParams
+from gajim.gtk.structs import ChatListEntryParam
+from gajim.gtk.structs import RemoveHistoryActionParams
+from gajim.gtk.structs import RetractMessageParam
+from gajim.gtk.util import GajimMenu
+from gajim.gtk.util import MenuItemListT
 
 UriMenuItemsT = list[tuple[str, list[str], str]]
 UriMenuBuilderT = Callable[[URI, str], UriMenuItemsT]
@@ -139,9 +141,13 @@ def get_groupchat_menu(contact: GroupchatContact) -> GajimMenu:
 
 def get_account_menu(account: str) -> GajimMenu:
 
+    client = app.get_client(account)
+    server_jid = client.get_own_jid().domain
+
     menuitems: MenuItemListT = [
         (_('Profile'), f'app.{account}-profile', account),
         (_('Discover Services…'), f'app.{account}-services', account),
+        (_('Execute Command…'), f'app.{account}-execute-command', server_jid),
         (_('Server Info'), f'app.{account}-server-info', account),
     ]
 
@@ -432,11 +438,21 @@ def get_roster_view_menu() -> GajimMenu:
     menuitems: MenuItemListT = [
         (_('Show Offline Contacts'), 'win.show-offline', None),
         (_('Sort by Status'), 'win.sort-by-show', None),
+        (_('Add Contact…'), 'app.add-contact', ''),
     ]
 
     return GajimMenu.from_list(menuitems)
 
 
+def get_account_notifications_menu(account: str) -> GajimMenu:
+    menuitems: MenuItemListT = [
+        (_('Deny all subscription requests'),
+         f'win.subscription-deny-all-{account}',
+         None),
+    ]
+    return GajimMenu.from_list(menuitems)
+
+
 def get_subscription_menu(account: str, jid: JID) -> GajimMenu:
     params = AddChatActionParams(account=account,
                                  jid=jid,
@@ -594,7 +610,7 @@ def get_groupchat_mod_menu(self_contact: types.GroupchatParticipant,
             value = GLib.Variant('as', [contact_name, 'participant'])
             menu.add_item(_('Grant Voice'), action, value)
         else:
-            value = value = GLib.Variant('as', [contact_name, 'visitor'])
+            value = GLib.Variant('as', [contact_name, 'visitor'])
             menu.add_item(_('Revoke Voice'), action, value)
 
     if not menu.get_n_items():
