@@ -14,17 +14,17 @@
 
 import logging
 
-from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import Gtk
 
 from gajim.common import app
 from gajim.common import passwords
 from gajim.common.events import PasswordRequired
 from gajim.common.i18n import _
 
-from .builder import get_builder
+from gajim.gtk.builder import get_builder
 
-log = logging.getLogger('gajim.gui.pass_dialog')
+log = logging.getLogger('gajim.gtk.pass_dialog')
 
 
 class PasswordDialog(Gtk.ApplicationWindow):
