@@ -13,50 +13,48 @@
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import annotations
+
 from typing import Any
-from typing import Optional
 from typing import cast
-from typing import Type
+from typing import Optional
 
 import logging
 import sys
 
-from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import Gtk
 
 from gajim.common import app
 from gajim.common import configpaths
-from gajim.common import helpers
 from gajim.common.const import THRESHOLD_OPTIONS
+from gajim.common.events import StyleChanged
+from gajim.common.events import ThemeUpdate
+from gajim.common.helpers import open_directory
 from gajim.common.i18n import _
-from gajim.common.helpers import open_file
 from gajim.common.multimedia_helpers import AudioInputManager
 from gajim.common.multimedia_helpers import AudioOutputManager
 from gajim.common.multimedia_helpers import VideoInputManager
-from gajim.common.events import StyleChanged
-from gajim.common.events import ThemeUpdate
-from gajim.common.setting_values import AllSettings
+from gajim.common.setting_values import BoolSettings
 
-from .const import Setting
-from .const import SettingKind
-from .const import SettingType
-from .controls.groupchat import GroupchatControl
-from .dialogs import DialogButton
-from .dialogs import ConfirmationDialog
-from .emoji_chooser import emoji_chooser
-from .settings import PopoverSetting
-from .settings import SettingsBox
-from .settings import SettingsDialog
-from .sidebar_switcher import SideBarSwitcher
-from .video_preview import VideoPreview
-from .util import open_window
-from .util import get_app_window
-from .builder import get_builder
+from gajim.gtk.builder import get_builder
+from gajim.gtk.const import Setting
+from gajim.gtk.const import SettingKind
+from gajim.gtk.const import SettingType
+from gajim.gtk.dialogs import ConfirmationDialog
+from gajim.gtk.dialogs import DialogButton
+from gajim.gtk.preview import PREVIEW_ACTIONS
+from gajim.gtk.settings import PopoverSetting
+from gajim.gtk.settings import SettingsBox
+from gajim.gtk.settings import SettingsDialog
+from gajim.gtk.sidebar_switcher import SideBarSwitcher
+from gajim.gtk.util import get_app_window
+from gajim.gtk.util import open_window
+from gajim.gtk.video_preview import VideoPreview
 
-if app.is_installed('GSPELL'):
-    from gi.repository import Gspell  # pylint: disable=ungrouped-imports
+# if app.is_installed('GSPELL'):
+#     from gi.repository import Gspell  # pylint: disable=ungrouped-imports
 
-log = logging.getLogger('gajim.gui.preferences')
+log = logging.getLogger('gajim.gtk.preferences')
 
 
 class Preferences(Gtk.ApplicationWindow):
@@ -81,11 +79,10 @@ class Preferences(Gtk.ApplicationWindow):
 
         self.add(self._ui.grid)
 
-        self._check_emoji_theme()
-
-        prefs: list[tuple[str, Type[PreferenceBox]]] = [
+        prefs: list[tuple[str, type[PreferenceBox]]] = [
             ('window_behaviour', WindowBehaviour),
             ('plugins', Plugins),
+            ('general', General),
             ('chats', Chats),
             ('group_chats', GroupChats),
             ('file_preview', FilePreview),
@@ -94,7 +91,6 @@ class Preferences(Gtk.ApplicationWindow):
             ('status_message', StatusMessage),
             ('automatic_status', AutomaticStatus),
             ('themes', Themes),
-            ('emoji', Emoji),
             ('server', Server),
             ('audio', Audio),
             ('video', Video),
@@ -116,18 +112,14 @@ class Preferences(Gtk.ApplicationWindow):
         self._ui.connect_signals(self)
 
         self.show_all()
-        if sys.platform != 'darwin':
-            # TODO: Remove if colored emoji rendering works well on
-            # Windows and MacOS
-            self._ui.emoji.hide()
 
     def get_ui(self):
         return self._ui
 
-    def _add_prefs(self, prefs: list[tuple[str, Type[PreferenceBox]]]):
+    def _add_prefs(self, prefs: list[tuple[str, type[PreferenceBox]]]):
         for ui_name, klass in prefs:
             pref_box = getattr(self._ui, ui_name)
-            pref = klass(self)
+            pref = klass(self)  # pyright: ignore
             pref_box.add(pref)
             self._prefs[ui_name] = pref
 
@@ -156,14 +148,6 @@ class Preferences(Gtk.ApplicationWindow):
         miscellaneous = cast(Miscellaneous, self._prefs['miscellaneous'])
         miscellaneous.update_proxy_list()
 
-    @staticmethod
-    def _check_emoji_theme() -> None:
-        # Ensure selected emoji theme is valid
-        emoji_themes = helpers.get_available_emoticon_themes()
-        settings_theme = app.settings.get('emoticons_theme')
-        if settings_theme not in emoji_themes:
-            app.settings.set('emoticons_theme', 'font')
-
     def _on_destroy(self, _widget: Gtk.Widget) -> None:
         self._prefs.clear()
         app.check_finalize(self)
@@ -172,7 +156,7 @@ class Preferences(Gtk.ApplicationWindow):
 class PreferenceBox(SettingsBox):
     def __init__(self, settings: list[Setting]) -> None:
         SettingsBox.__init__(self, None)
-        self.get_style_context().add_class('settings-border')
+        self.get_style_context().add_class('border')
         self.set_selection_mode(Gtk.SelectionMode.NONE)
         self.set_vexpand(False)
         self.set_valign(Gtk.Align.END)
@@ -259,7 +243,7 @@ class Plugins(PreferenceBox):
         PreferenceBox.__init__(self, settings)
 
 
-class Chats(PreferenceBox):
+class General(PreferenceBox):
     def __init__(self, *args: Any) -> None:
 
         speller_desc = None
@@ -268,44 +252,33 @@ class Chats(PreferenceBox):
 
         settings = [
             Setting(SettingKind.SWITCH,
-                    _('Spell Checking'),
+                    _('Close with Escape'),
                     SettingType.CONFIG,
-                    'use_speller',
-                    desc=speller_desc,
-                    enabled_func=self._speller_available,
-                    callback=self._on_use_speller),
-
-            Setting(SettingKind.SWITCH,
-                    _('Message Receipts (✔)'),
-                    SettingType.CONFIG,
-                    'positive_184_ack',
-                    desc=_('Add a checkmark to received messages')),
-
-            # Setting(SettingKind.SWITCH,
-            #         _('XHTML Formatting'),
-            #         SettingType.CONFIG,
-            #         'show_xhtml',
-            #         desc=_('Render XHTML styles (colors, etc.) of incoming '
-            #                'messages')),
+                    'escape_key_closes',
+                    desc=_('Close a chat by pressing the Escape key')),
 
             Setting(SettingKind.SWITCH,
                     _('Show Send Message Button'),
                     SettingType.CONFIG,
-                    'show_send_message_button',
-                    callback=self._on_show_send_message_button),
+                    'show_send_message_button'),
 
             Setting(SettingKind.SWITCH,
-                    _('Show Status Changes'),
+                    _('Send Messages with Control+Enter'),
                     SettingType.CONFIG,
-                    'print_status_in_chats',
-                    desc=_('For example: "Julia is now online"')),
+                    'send_on_ctrl_enter'),
 
             Setting(SettingKind.SWITCH,
-                    _('Show Chat State In Banner'),
+                    _('Spell Checking'),
                     SettingType.CONFIG,
-                    'show_chatstate_in_banner',
-                    desc=_('Show the contact’s chat state (e.g. typing) in '
-                           'the chats tab’s banner')),
+                    'use_speller',
+                    desc=speller_desc,
+                    enabled_func=self._speller_available),
+
+            Setting(SettingKind.SWITCH,
+                    _('Emoji Shortcodes'),
+                    SettingType.CONFIG,
+                    'enable_emoji_shortcodes',
+                    desc=_('Show suggestions for shortcodes, e.g. :+1:')),
         ]
 
         PreferenceBox.__init__(self, settings)
@@ -314,26 +287,26 @@ class Chats(PreferenceBox):
     def _speller_available() -> bool:
         return app.is_installed('GSPELL')
 
-    @staticmethod
-    def _on_use_speller(value: bool, *args: Any) -> None:
-        if not value:
-            return
 
-        lang = app.settings.get('speller_language')
-        gspell_lang = Gspell.language_lookup(lang)
-        if gspell_lang is None:
-            gspell_lang = Gspell.language_get_default()
-        if gspell_lang is None:
-            return
-        app.settings.set('speller_language', gspell_lang.get_code())
-        for ctrl in app.window.get_controls():
-            ctrl.set_speller()
+class Chats(PreferenceBox):
+    def __init__(self, *args: Any) -> None:
 
-    @staticmethod
-    def _on_show_send_message_button(show_button: bool, *args: Any) -> None:
-        # Bind to send_on_ctrl_enter to make this setting user-friendly
-        # This way, users can press Enter to insert a new line, then click Send
-        app.settings.set('send_on_ctrl_enter', show_button)
+        settings = [
+            Setting(SettingKind.SWITCH,
+                    _('Message Receipts (✔)'),
+                    SettingType.CONFIG,
+                    'positive_184_ack',
+                    desc=_('Add a checkmark to received messages')),
+
+            Setting(SettingKind.SWITCH,
+                    _('Show Status Changes'),
+                    SettingType.CONFIG,
+                    'print_status_in_chats',
+                    desc=_('For example: "Julia is now online"')),
+
+        ]
+
+        PreferenceBox.__init__(self, settings)
 
 
 class GroupChats(PreferenceBox):
@@ -397,19 +370,13 @@ class GroupChats(PreferenceBox):
 
     @staticmethod
     def _on_sort_by_show_in_muc(_value: bool, *args: Any) -> None:
-        for ctrl in app.window.get_controls():
-            if ctrl.is_groupchat:
-                assert isinstance(ctrl, GroupchatControl)
-                if ctrl.roster is not None:
-                    ctrl.roster.invalidate_sort()
+        roster = app.window.get_control().get_group_chat_roster()
+        roster.invalidate_sort()
 
     @staticmethod
     def _on_show_status_in_roster(_value: bool, *args: Any) -> None:
-        for ctrl in app.window.get_controls():
-            if ctrl.is_groupchat:
-                assert isinstance(ctrl, GroupchatControl)
-                if ctrl.roster is not None:
-                    ctrl.roster.draw_contacts()
+        roster = app.window.get_control().get_group_chat_roster()
+        roster.draw_contacts()
 
     @staticmethod
     def _reset_join_left(button: Gtk.Button) -> None:
@@ -432,55 +399,65 @@ class FilePreview(PreferenceBox):
             10485760: '10 MiB',
         }
 
-        actions = {
-            'open': _('Open'),
-            'save_as': _('Save As…'),
-            'open_folder': _('Open Folder'),
-            'copy_link_location': _('Copy Link Location'),
-            'open_link_in_browser': _('Open Link in Browser'),
-        }
+        preview_actions = {}
+        for action, data in PREVIEW_ACTIONS.items():
+            if action == 'download':
+                continue
+            preview_actions[action] = data[0]
 
         settings = [
+            Setting(SettingKind.SWITCH,
+                    _('File Preview'),
+                    SettingType.CONFIG,
+                    'enable_file_preview',
+                    desc=_('Show previews for files')),
             Setting(SettingKind.SPIN,
                     _('Preview Size'),
                     SettingType.CONFIG,
                     'preview_size',
-                    desc=_('Size of preview image'),
+                    desc=_('Size of preview images in pixels'),
+                    bind='enable_file_preview',
                     props={'range_': (100, 1000)}),
 
             Setting(SettingKind.POPOVER,
-                    _('Allowed File Size'),
+                    _('File Size Limit'),
                     SettingType.CONFIG,
                     'preview_max_file_size',
-                    desc=_('Maximum file size for preview generation'),
+                    desc=_('Maximum file size for preview downloads'),
+                    bind='enable_file_preview',
                     props={'entries': sizes}),
 
             Setting(SettingKind.SWITCH,
                     _('Preview in Public Group Chats'),
                     SettingType.CONFIG,
                     'preview_anonymous_muc',
-                    desc=_('Generate preview automatically in public '
-                           'group chats (may disclose your data)')),
+                    desc=_('Show previews automatically in public '
+                           'group chats (may disclose your data)'),
+                    bind='enable_file_preview'),
 
             Setting(SettingKind.SWITCH,
                     _('Preview all Image URLs'),
                     SettingType.CONFIG,
                     'preview_allow_all_images',
-                    desc=_('Generate preview for any URLs containing images '
-                           '(may be unsafe)')),
+                    desc=_('Show previews for any URLs containing images '
+                           '(may be unsafe)'),
+                    bind='enable_file_preview'),
 
             Setting(SettingKind.POPOVER,
                     _('Left Click Action'),
                     SettingType.CONFIG,
                     'preview_leftclick_action',
-                    desc=_('Action when left-clicking a preview'),
-                    props={'entries': actions}),
+                    desc=_('Action for left-clicking a preview'),
+                    bind='enable_file_preview',
+                    props={'entries': preview_actions}),
 
             Setting(SettingKind.SWITCH,
                     _('HTTPS Verification'),
                     SettingType.CONFIG,
                     'preview_verify_https',
-                    desc=_('Whether to check for a valid certificate')),
+                    desc=_('Whether to check for a valid certificate before '
+                           'downloading (not safe to disable)'),
+                    bind='enable_file_preview'),
         ]
 
         PreferenceBox.__init__(self, settings)
@@ -572,14 +549,14 @@ class AutomaticStatus(PreferenceBox):
             Setting(SettingKind.AUTO_AWAY,
                     _('Auto Away'),
                     SettingType.DIALOG,
-                    desc=_('Change your status to \'Away\' after a certain '
+                    desc=_('Change your status to "Away" after a certain '
                            'amount of time'),
                     props={'dialog': AutoAwayDialog}),
 
             Setting(SettingKind.AUTO_EXTENDED_AWAY,
                     _('Auto Not Available'),
                     SettingType.DIALOG,
-                    desc=_('Change your status to \'Not Available\' after a '
+                    desc=_('Change your status to "Not Available" after a '
                            'certain amount of time'),
                     props={'dialog': AutoExtendedAwayDialog}),
 
@@ -710,40 +687,6 @@ class Themes(PreferenceBox):
         app.ged.raise_event(StyleChanged())
 
 
-class Emoji(PreferenceBox):
-    def __init__(self, *args: Any) -> None:
-        if sys.platform != 'darwin':
-            # TODO: Remove if colored emoji rendering works well on
-            # Windows and MacOS
-            PreferenceBox.__init__(self, [])
-            return
-
-        emoji_themes_items: list[str] = []
-        for theme in helpers.get_available_emoticon_themes():
-            emoji_themes_items.append(theme)
-
-        settings = [
-            Setting(SettingKind.POPOVER,
-                    _('Emoji Theme'),
-                    SettingType.CONFIG,
-                    'emoticons_theme',
-                    desc=_('Choose from various emoji styles'),
-                    props={'entries': emoji_themes_items},
-                    callback=self._on_emoticons_theme)
-        ]
-
-        PreferenceBox.__init__(self, settings)
-
-    def _on_emoticons_theme(self, *args: Any) -> None:
-        emoji_chooser.load()
-        self._toggle_emoticons()
-
-    @staticmethod
-    def _toggle_emoticons() -> None:
-        for ctrl in app.window.get_controls():
-            ctrl.toggle_emoticons()
-
-
 class Server(PreferenceBox):
     def __init__(self, *args: Any) -> None:
 
@@ -921,7 +864,7 @@ class Video(PreferenceBox):
 
 class Miscellaneous(PreferenceBox):
     def __init__(self, pref_window: Preferences) -> None:
-        self._hints_list: list[AllSettings] = [
+        self._hints_list: list[BoolSettings] = [
             'show_help_start_chat',
         ]
 
@@ -955,7 +898,7 @@ class Miscellaneous(PreferenceBox):
 
         reset_button = pref_window.get_ui().reset_button
         reset_button.connect('clicked', self._on_reset_hints)
-        reset_button.set_sensitive(self._check_hints_reset)
+        reset_button.set_sensitive(self._check_hints_reset())
 
         purge_history_button = pref_window.get_ui().purge_history_button
         purge_history_button.connect('clicked', self._on_purge_history_clicked)
@@ -973,10 +916,7 @@ class Miscellaneous(PreferenceBox):
         popover_row.update_entries(self._get_proxies())
 
     def _check_hints_reset(self) -> bool:
-        for hint in self._hints_list:
-            if app.settings.get(hint) is False:
-                return True
-        return False
+        return any(app.settings.get(hint) is False for hint in self._hints_list)
 
     def _on_reset_hints(self, button: Gtk.Button) -> None:
         for hint in self._hints_list:
@@ -1035,7 +975,7 @@ class Advanced(PreferenceBox):
 
     @staticmethod
     def _on_open_debug_logs(*args: Any) -> None:
-        open_file(configpaths.get('DEBUG'))
+        open_directory(configpaths.get('DEBUG'))
 
     @staticmethod
     def _on_advanced_config_editor(*args: Any) -> None:
