@@ -20,15 +20,13 @@ from typing import Optional
 
 import locale
 import logging
-
-from enum import IntEnum
 from collections import defaultdict
+from enum import IntEnum
 
 from gi.repository import Gdk
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import Gtk
-
 from nbxmpp import JID
 from nbxmpp.const import PresenceShow
 from nbxmpp.namespaces import Namespace
@@ -37,27 +35,26 @@ from gajim.common import app
 from gajim.common import ged
 from gajim.common import types
 from gajim.common.const import AvatarSize
-from gajim.common.const import StyleAttr
 from gajim.common.const import PresenceShowExt
+from gajim.common.const import StyleAttr
 from gajim.common.events import ApplicationEvent
 from gajim.common.events import RosterPush
 from gajim.common.events import RosterReceived
 from gajim.common.helpers import event_filter
 from gajim.common.i18n import _
 
-from .menus import get_roster_menu
-from .dialogs import ConfirmationDialog
-from .dialogs import DialogButton
-from .tooltips import RosterTooltip
-from .util import EventHelper
-from .builder import get_builder
-from .util import open_window
+from gajim.gtk.builder import get_builder
+from gajim.gtk.dialogs import ConfirmationDialog
+from gajim.gtk.dialogs import DialogButton
+from gajim.gtk.menus import get_roster_menu
+from gajim.gtk.tooltips import RosterTooltip
+from gajim.gtk.util import EventHelper
+from gajim.gtk.util import GajimPopover
+from gajim.gtk.util import open_window
 
-log = logging.getLogger('gajim.gui.roster')
+log = logging.getLogger('gajim.gtk.roster')
 
 
-HANDLED_EVENTS = []
-
 DEFAULT_GROUP = _('Contacts')
 
 
@@ -79,6 +76,7 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
 
         self._account = account
         self._client = app.get_client(account)
+        self._contacts = self._client.get_module('Contacts')
 
         self._roster_tooltip = RosterTooltip()
 
@@ -116,8 +114,6 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
         self._ui.connect_signals(self)
 
         self.register_events([
-            ('account-connected', ged.CORE, self._on_account_state),
-            ('account-disconnected', ged.CORE, self._on_account_state),
             ('roster-received', ged.CORE, self._on_roster_received),
             ('theme-update', ged.GUI2, self._on_theme_update),
             ('roster-push', ged.GUI2, self._on_roster_push),
@@ -134,73 +130,31 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
         self._filter_enabled = False
         self._filter_string = ''
 
-        self._add_actions()
+        app.settings.connect_signal('showoffline', self._on_setting_changed)
+        app.settings.connect_signal('sort_by_show_in_roster',
+                                    self._on_setting_changed)
+
+        self._connect_actions()
         self._initial_draw()
 
-    def _add_actions(self):
-        actions = [
-            ('contact-info', self._on_contact_info),
-            ('modify-gateway', self._on_modify_gateway),
-            ('execute-command', self._on_execute_command),
-            ('block-contact', self._on_block_contact),
-            ('remove-contact', self._on_remove_contact),
+    def _connect_actions(self):
+        app_actions = [
+            (f'{self._account}-contact-info', self._on_contact_info),
+            (f'{self._account}-modify-gateway', self._on_modify_gateway),
+            (f'{self._account}-execute-command', self._on_execute_command),
+            (f'{self._account}-block-contact', self._on_block_contact),
+            (f'{self._account}-remove-contact', self._on_remove_contact),
         ]
-        for action in actions:
+
+        for action in app_actions:
             action_name, func = action
-            act = Gio.SimpleAction.new(
-                f'{action_name}-{self._account}', GLib.VariantType.new('s'))
-            act.connect('activate', func)
-            app.window.add_action(act)
-
-        action = Gio.SimpleAction.new_stateful(
-            f'show-offline-{self._account}',
-            None,
-            GLib.Variant.new_boolean(app.settings.get('showoffline')))
-        action.connect('change-state', self._on_show_offline)
-        app.window.add_action(action)
-
-        action = Gio.SimpleAction.new_stateful(
-            f'sort-by-show-{self._account}',
-            None,
-            GLib.Variant.new_boolean(
-                app.settings.get('sort_by_show_in_roster')))
-        action.connect('change-state', self._on_sort_by_show)
-        app.window.add_action(action)
-
-    def update_actions(self):
-        online = app.account_is_connected(self._account)
-        blocking_support = self._client.get_module('Blocking').supported
-
-        actions = [('contact-info', online),
-                   ('modify-gateway', online),
-                   ('execute-command', online),
-                   ('block-contact', online and blocking_support),
-                   ('remove-contact', online)]
-
-        for action, enabled in actions:
-            act = app.window.lookup_action(f'{action}-{self._account}')
-            assert act is not None
-            act.set_enabled(enabled)
-
-    def _remove_actions(self):
-        actions = [
-            'contact-info',
-            'modify-gateway',
-            'execute-command',
-            'block-contact',
-            'remove-contact',
-            'show-offline',
-            'sort-by-show',
-        ]
-        for action in actions:
-            app.window.remove_action(f'{action}-{self._account}')
+            action = app.app.lookup_action(action_name)
+            assert action is not None
+            action.connect('activate', func)
 
     def _get_contact(self, jid: str) -> types.BareContact:
         return self._client.get_module('Contacts').get_contact(jid)
 
-    def _on_account_state(self, _event: ApplicationEvent) -> None:
-        self.update_actions()
-
     def _on_theme_update(self, _event: ApplicationEvent) -> None:
         self.redraw()
 
@@ -300,25 +254,13 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
             self._roster_tooltip.clear_tooltip()
             return False
 
-        contact = self._get_contact(model[iter_][Column.JID_OR_GROUP])
+        contact = self._contacts.get_bare_contact(
+            model[iter_][Column.JID_OR_GROUP])
         value, widget = self._roster_tooltip.get_tooltip(path, contact)
         tooltip.set_custom(widget)
         return value
 
-    def _on_show_offline(self,
-                         action: Gio.SimpleAction,
-                         value: Optional[GLib.Variant]) -> None:
-
-        assert value is not None
-        action.set_state(value)
-        app.settings.set('showoffline', value.get_boolean())
-        self._refilter()
-
-    def _on_sort_by_show(self,
-                         action: Gio.SimpleAction,
-                         value: GLib.Variant) -> None:
-        action.set_state(value)
-        app.settings.set('sort_by_show_in_roster', value.get_boolean())
+    def _on_setting_changed(self, *args: Any) -> None:
         self._refilter()
 
     def _on_contact_info(self,
@@ -352,7 +294,7 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
                            param: GLib.Variant):
 
         jid = JID.from_string(param.get_string())
-        selected_contact = self._client.get_module('Contacts').get_contact(jid)
+        selected_contact = self._contacts.get_contact(jid)
         if selected_contact.is_gateway:
             # Check for transport users in roster and warn about removing the
             # transport if there are any
@@ -369,7 +311,7 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
             if has_transport_contacts:
                 ConfirmationDialog(
                     _('Remove Transport'),
-                    _('Transport \'%s\' will be '
+                    _('Transport "%s" will be '
                       'removed') % selected_contact.name,
                     _('You will no longer be able to send and receive '
                       'messages from and to contacts using this transport.'),
@@ -438,21 +380,12 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
                            treeview: Gtk.TreeView,
                            event: Gdk.EventButton) -> None:
 
-        contact = self._client.get_module('Contacts').get_contact(jid)
+        contact = self._contacts.get_bare_contact(jid)
         gateway_register = contact.is_gateway and contact.supports(
             Namespace.REGISTER)
-        menu = get_roster_menu(
-            self._account, jid, gateway=gateway_register)
 
-        rectangle = Gdk.Rectangle()
-        rectangle.x = int(event.x)
-        rectangle.y = int(event.y)
-        rectangle.width = rectangle.height = 1
-
-        popover = Gtk.Popover.new_from_model(self, menu)
-        popover.set_relative_to(treeview)
-        popover.set_position(Gtk.PositionType.RIGHT)
-        popover.set_pointing_to(rectangle)
+        menu = get_roster_menu(self._account, jid, gateway=gateway_register)
+        popover = GajimPopover(menu, relative_to=treeview, event=event)
         popover.popup()
 
     def set_search_string(self, text: str) -> None:
@@ -529,7 +462,6 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
                            _signal_name: str) -> None:
 
         self._draw_contact(contact)
-        self._refilter()
 
     @event_filter(['account'])
     def _on_roster_received(self, _event: RosterReceived) -> None:
@@ -537,7 +469,7 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
 
     @event_filter(['account'])
     def _on_roster_push(self, event: RosterPush) -> None:
-        contact = self._get_contact(str(event.item.jid))
+        contact = self._contacts.get_contact(str(event.item.jid))
 
         if event.item.subscription == 'remove':
             contact.disconnect(self)
@@ -665,7 +597,8 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
         for group in self._store:
             group_is_visible = False
             for child in group.iterchildren():
-                contact = self._get_contact(child[Column.JID_OR_GROUP])
+                contact = self._contacts.get_bare_contact(
+                    child[Column.JID_OR_GROUP])
                 is_visible = self._get_contact_visible(contact)
                 child[Column.VISIBLE] = is_visible
                 if is_visible:
@@ -693,6 +626,7 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
         surface = contact.get_avatar(
             AvatarSize.ROSTER, self.get_scale_factor())
         self._store[iter_][Column.AVATAR] = surface
+        self._store[iter_][Column.VISIBLE] = self._get_contact_visible(contact)
 
     def _get_total_user_count(self) -> int:
         count = 0
@@ -746,9 +680,9 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
                             iter1: Gtk.TreeIter,
                             iter2: Gtk.TreeIter,
                             _user_data: Literal[None]):
-        """
+        '''
         Compare two iterators to sort them
-        """
+        '''
 
         is_contact = model.iter_parent(iter1)
         if is_contact:
@@ -758,8 +692,10 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
             if not app.settings.get('sort_by_show_in_roster'):
                 return locale.strcoll(name1.lower(), name2.lower())
 
-            contact1 = self._get_contact(model[iter1][Column.JID_OR_GROUP])
-            contact2 = self._get_contact(model[iter2][Column.JID_OR_GROUP])
+            contact1 = self._contacts.get_bare_contact(
+                model[iter1][Column.JID_OR_GROUP])
+            contact2 = self._contacts.get_bare_contact(
+                model[iter2][Column.JID_OR_GROUP])
 
             if contact1.show != contact2.show:
                 if contact1.show == PresenceShow.DND:
@@ -780,12 +716,8 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
         self._group_refs.clear()
         self._store.clear()
 
-    def process_event(self, event: ApplicationEvent) -> None:
-        if event.name not in HANDLED_EVENTS:
-            return
-
     def _on_destroy(self, _roster: Roster) -> None:
-        self._remove_actions()
+        app.settings.disconnect_signals(self)
         self._contact_refs.clear()
         self._group_refs.clear()
         self._unset_model()
@@ -795,4 +727,5 @@ class Roster(Gtk.ScrolledWindow, EventHelper):
         del self._roster
         del self._store
         del self._roster_tooltip
+        del self._contacts
         app.check_finalize(self)
